"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const globby_1 = __importDefault(require("globby"));
const lodash_1 = require("lodash");
const defaultOptions = {
    dot: true,
    expandDirectories: true,
    gitignore: false,
    onlyFiles: true,
};
/**
 * https://github.com/sindresorhus/globby#api
 * https://github.com/mrmlnc/fast-glob#options-1
 */
function findFiles(context, globs, options) {
    return __awaiter(this, void 0, void 0, function* () {
        const globbyOptions = lodash_1.merge({ cwd: context.cwd }, defaultOptions, options);
        return globby_1.default(globs, globbyOptions);
    });
}
exports.findFiles = findFiles;
function findOneFileOrError(context, glob, options) {
    return __awaiter(this, void 0, void 0, function* () {
        const filenames = yield findFiles(context, glob, options);
        if (filenames.length === 0) {
            throw new Error("File not found: " + JSON.stringify(glob));
        }
        if (filenames.length !== 1) {
            throw new Error("Only one source file allowed: " + JSON.stringify(glob));
        }
        return filenames[0];
    });
}
exports.findOneFileOrError = findOneFileOrError;
function findOneFileOrWarn(context, glob, options) {
    return __awaiter(this, void 0, void 0, function* () {
        const filenames = yield findFiles(context, glob, options);
        if (filenames.length === 0) {
            context.logger.warn("File not found: " + JSON.stringify(glob));
            return filenames[0];
        }
        if (filenames.length !== 1) {
            context.logger.warn("File ambiguous: " + JSON.stringify(glob) + ": " + JSON.stringify(filenames, null, 2));
            return filenames[0];
        }
        return filenames[0];
    });
}
exports.findOneFileOrWarn = findOneFileOrWarn;
//# sourceMappingURL=find.js.map