"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const graceful_fs_1 = __importDefault(require("graceful-fs"));
const path_1 = __importDefault(require("path"));
const util_1 = require("util");
const find_1 = require("./find");
const fsReadFile = util_1.promisify(graceful_fs_1.default.readFile);
function readFile(context, glob) {
    const read = () => __awaiter(this, void 0, void 0, function* () {
        const filename = yield find_1.findOneFileOrWarn(context, glob);
        if (!filename) {
            return Promise.resolve(undefined);
        }
        const sourceFile = path_1.default.join(context.cwd, filename);
        return fsReadFile(sourceFile, "utf8");
    });
    return new ReadAs(read);
}
exports.readFile = readFile;
class ReadAs {
    constructor(read) {
        this.read = read;
    }
    asText() {
        return __awaiter(this, void 0, void 0, function* () {
            return this.read();
        });
    }
    asJson() {
        return __awaiter(this, void 0, void 0, function* () {
            const text = yield this.read();
            return text ? JSON.parse(text) : null;
        });
    }
    asLines() {
        return __awaiter(this, void 0, void 0, function* () {
            const text = yield this.read();
            return text
                ? text.split(/[\r\n]+/).map(line => line.trim()).filter(line => line)
                : undefined;
        });
    }
}
exports.ReadAs = ReadAs;
//# sourceMappingURL=read.js.map