"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const graceful_fs_1 = __importDefault(require("graceful-fs"));
const path_1 = __importDefault(require("path"));
const util_1 = require("util");
const fsWriteFile = util_1.promisify(graceful_fs_1.default.writeFile);
const finalNewLine = "\n";
function writeFile(context, filename) {
    const write = (text) => __awaiter(this, void 0, void 0, function* () {
        if (text) {
            const file = path_1.default.join(context.cwd, filename);
            const content = text.trim() + finalNewLine;
            yield fsWriteFile(file, content, "utf8");
        }
    });
    return new WriteAs(write);
}
exports.writeFile = writeFile;
class WriteAs {
    constructor(write) {
        this.write = write;
    }
    asText(text) {
        return __awaiter(this, void 0, void 0, function* () {
            yield this.write(text);
        });
    }
    asJson(value) {
        return __awaiter(this, void 0, void 0, function* () {
            const text = value ? JSON.stringify(value, null, 2) : value;
            yield this.write(text);
        });
    }
    asLines(value) {
        return __awaiter(this, void 0, void 0, function* () {
            const text = value ? value.join("\n") : value;
            yield this.write(text);
        });
    }
}
exports.WriteAs = WriteAs;
//# sourceMappingURL=write.js.map